use x86_64::structures::gdt::{Descriptor, GlobalDescriptorTable};

use lazy_static::lazy_static;

use crate::log::{LOGGER, LogLevel};
use crate::{critical_section, format, log_trace};

lazy_static! {
    pub static ref GDT: GlobalDescriptorTable = {
        let mut gdt = GlobalDescriptorTable::new();
        gdt.append(Descriptor::kernel_code_segment());
        gdt
    };
}

#[allow(dead_code)]
pub fn setup_gdt() {
    critical_section!({
        GDT.load();
        log_trace!(
            "GDT: Setting up global descriptor table at 0x{:x}",
            core::ptr::addr_of!(GDT) as usize
        );
    });
}
